==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlaneDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安措费使用计划E明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_plane_detail")
public class PlaneDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private Long planId; // 主表主键ID
    @TableField(value="detail_name")
    private String detailName; // 安全费用项目名称
    @TableField(value="detail_mny")
    private BigDecimal detailMny; // 拟投入金额（万元）
    @TableField(value="detail_date")
    private Date detailDate; // 使用时间
    @TableField(value="detail_description")
    private String detailDescription; // 安措费使用计发文说明
    
    
    

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public Date getDetailDate() {
        return detailDate;
    }

    public void setDetailDate(Date detailDate) {
        this.detailDate = detailDate;
    }
    public String getDetailDescription() {
        return detailDescription;
    }

    public void setDetailDescription(String detailDescription) {
        this.detailDescription = detailDescription;
    }
    
}

==> ejc-jltest-impl-3.0.0-20240328.021343-126-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlaneDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安措费使用计划E明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_plane_detail")
public class PlaneDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private Long planId; // 主表主键ID
    @TableField(value="detail_name")
    private String detailName; // 安全费用项目名称
    @TableField(value="detail_mny")
    private BigDecimal detailMny; // 拟投入金额（万元）
    @TableField(value="detail_date")
    private Date detailDate; // 使用时间
    @TableField(value="detail_description")
    private String detailDescription; // 安措费使用计发文说明
    @TableField(value="detail_max_mny")
    private BigDecimal detailMaxMny; // 最大拟投入金额
    @TableField(value="org_id")
    private Long orgId; // 组织ID
    @TableField(value="org_type")
    private Integer orgType; // 组织类别（1-集团，2-分公司，3-项目部）
    @TableField(value="org_name")
    private String orgName; // 组织名称
    
    
    

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public Date getDetailDate() {
        return detailDate;
    }

    public void setDetailDate(Date detailDate) {
        this.detailDate = detailDate;
    }
    public String getDetailDescription() {
        return detailDescription;
    }

    public void setDetailDescription(String detailDescription) {
        this.detailDescription = detailDescription;
    }
    public BigDecimal getDetailMaxMny() {
        return detailMaxMny;
    }

    public void setDetailMaxMny(BigDecimal detailMaxMny) {
        this.detailMaxMny = detailMaxMny;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Integer getOrgType() {
        return orgType;
    }

    public void setOrgType(Integer orgType) {
        this.orgType = orgType;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}
